@@ -1,5 +1,5 @@
 package Ryu::Source;
-$Ryu::Source::VERSION = '0.009';
+$Ryu::Source::VERSION = '0.010';
 use strict;
 use warnings;
 
@@ -159,10 +159,6 @@ sub from {
 
 =head2 encode
 
-=cut
-
-=head2 encode
-
 Passes each item through an encoder.
 
 The first parameter is the encoder to use, the remainder are
@@ -209,6 +205,31 @@ sub decode {
     }, $src);
 }
 
+=head2 say
+
+Shortcut for C< ->each(sub { print "\n" }) >.
+
+=cut
+
+sub say {
+    my ($self) = @_;
+    $self->each(sub { print "$_\n" });
+}
+
+=head2 print
+
+Shortcut for C< ->each(sub { print }) >, except this will
+also save the initial state of C< $\ > and use that for each
+call for consistency.
+
+=cut
+
+sub print {
+    my ($self) = @_;
+    my $delim = $\;
+    $self->each(sub { local $\ = $delim; print });
+}
+
 =head2 empty
 
 Creates an empty source, which finishes immediately.
@@ -1211,5 +1232,5 @@ Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2016. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2017. Licensed under the same terms as Perl itself.
 
